@@ -207,7 +207,7 @@ class AISyntheticGenerator:
         if(decompress):
             compressedFile = folder+".tar.gz"
             with tarfile.open(compressedFile) as tar:
-                tar.extractall(folder)
+                tar.extractall(self.modelsDir)
         self.model = tf.keras.models.load_model(folder)
         return self.model       
 
@@ -222,7 +222,7 @@ class AISyntheticGenerator:
         with open(compressedFilePath, "wb") as download_file:
             download_file.write(container_client.download_blob(uri).readall())
         with tarfile.open(compressedFilePath) as tar:
-            tar.extractall(folder)
+            tar.extractall(self.modelsDir)
         self.model = tf.keras.models.load_model(folder)
         return self.model           
 
